package com.yunzhi.demo.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.demo.common.BaseController;
import com.yunzhi.demo.common.Constants;
import com.yunzhi.demo.common.ResponseBean;
import com.yunzhi.demo.common.StringUtils;
import com.yunzhi.demo.entity.TaPost;
import com.yunzhi.demo.service.ITaPointsLogService;
import com.yunzhi.demo.service.ITaPostService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.demo.service.ITaPostTestService;
import com.yunzhi.demo.entity.TaPostTest;

import java.util.List;

/**
 * <p>
    * 题库 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-04-15
 */

@Api(tags = "题库")
@RestController
@RequestMapping("/")
public class TaPostTestController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaPostTestController.class);

    @Autowired
    ITaPostTestService iTaPostTestService;

    @Autowired
    ITaPostService iTaPostService;

    @Autowired
    ITaPointsLogService iTaPointsLogService;

    @PostMapping("/ma/answer-test")
    public ResponseBean answerPostTest(@ApiParam("答题内容") @RequestBody List<TaPostTest> postTestList) throws Exception {
        if (null == postTestList || postTestList.size() == 0) {
            throw new Exception("未发现答题内容");
        }

        String postId = postTestList.get(0).getPostId();
        TaPost taPost = iTaPostService.getById(postId);
        if (null == taPost || Constants.STATUS_DELETED.equals(taPost.getStatus())) {
            throw new Exception("答题文章内容不存在");
        }

        if (null != taPost.getAnswerNum() && taPost.getAnswerNum() > postTestList.size()) {
            throw new Exception(String.format("当前知识需至少答 %d 题", taPost.getAnswerNum()));
        }

        boolean allRight = true;
        for(int i = 0; i < postTestList.size(); i++) {
            TaPostTest myTest = postTestList.get(i);
            TaPostTest postTest = iTaPostTestService.getById(myTest.getSerialNo());
            if (null == postTest || StringUtils.isEmpty(postTest.getCorrectAnswers())) {
                throw new Exception("部分考题未设置正确答案, 请退出重试");
            }

            String myAnswer = myTest.getCorrectAnswers();
            if (StringUtils.isEmpty(myAnswer)) {
                throw new Exception("部分考题未作答");
            }

            boolean isRight = iTaPostTestService.checkAnswer(postTest.getCorrectAnswers(), myAnswer);
            myTest.setIsRight(isRight);

            allRight = allRight && isRight;
        }

        if (!allRight) {
            return ResponseBean.error("答题失败", ResponseBean.ERROR_UNAVAILABLE, postTestList);
        }

        // 奖励积分
        iTaPointsLogService.sendPoints(taPost, getCurrentPerson());

        return ResponseBean.success("答题全对");
    }


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taPostTest",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taPostTestList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

		    IPage<TaPostTest> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaPostTest> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaPostTest> result = iTaPostTestService.page(pg, queryWrapper);
            return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taPostTest 实体对象
     * @return
     */
    @RequestMapping(value="/admin/post-test",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taPostTestAdd(@ApiParam("保存内容") @RequestBody TaPostTest taPostTest) throws Exception{

        if (iTaPostTestService.save(taPostTest)){
            return ResponseBean.success(taPostTest);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taPostTest/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taPostTestDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        if(iTaPostTestService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taPostTest 实体对象
     * @return
     */
    @RequestMapping(value="/taPostTest/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taPostTestUpdate(@ApiParam("对象ID") @PathVariable Integer id,
                                        @ApiParam("更新内容") @RequestBody TaPostTest taPostTest) throws Exception{

        if (iTaPostTestService.updateById(taPostTest)){
            return ResponseBean.success(iTaPostTestService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taPostTest/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taPostTestGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        return ResponseBean.success(iTaPostTestService.getById(id));
    }
}
